Range-v3: range/v3/algorithm/search_n.hpp File Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Classes | Typedefs | Variables
search_n.hpp File Reference

## Classes
struct | ranges::v3::search_n_fn

## Typedefs
template<typename I , typename V , typename C = equal_to, typename P = ident>
using | ranges::v3::Searchnable = meta::strict_and< ForwardIterator< I >, IndirectRelation< C, projected< I, P >, V const * > >
| ingroup group-concepts

## Variables
constexpr with_braced_init_args< search_n_fn > | ranges::v3::search_n {}